@@ -16,13 +16,14 @@ from .extensions import ClientExtensionFactory, Extension
 from .headers import (
     build_authorization_basic,
     build_extension,
+    build_host,
     build_subprotocol,
     parse_connection,
     parse_extension,
     parse_subprotocol,
     parse_upgrade,
 )
-from .http import USER_AGENT, build_host
+from .http import USER_AGENT
 from .http11 import Request, Response
 from .typing import (
     ConnectionOption,
@@ -73,7 +74,7 @@ class ClientConnection(Connection):
         extensions: Optional[Sequence[ClientExtensionFactory]] = None,
         subprotocols: Optional[Sequence[Subprotocol]] = None,
         state: State = CONNECTING,
-        max_size: Optional[int] = 2 ** 20,
+        max_size: Optional[int] = 2**20,
         logger: Optional[LoggerLike] = None,
     ):
         super().__init__(
@@ -200,7 +201,7 @@ class ClientConnection(Connection):
         client configuration. If no match is found, an exception is raised.
 
         If several variants of the same extension are accepted by the server,
-        it may be configured severel times, which won't make sense in general.
+        it may be configured several times, which won't make sense in general.
         Extensions must implement their own requirements. For this purpose,
         the list of previously accepted extensions is provided.
 
